@@ -5,7 +5,7 @@ package JSON::Schema::Modern::Document::OpenAPI;
 # ABSTRACT: One OpenAPI v3.1 document
 # KEYWORDS: JSON Schema data validation request response OpenAPI
 
-our $VERSION = '0.040';
+our $VERSION = '0.041';
 
 use 5.020;
 use Moo;
@@ -15,7 +15,7 @@ use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
-use JSON::Schema::Modern::Utilities 0.525 qw(assert_keyword_exists assert_keyword_type E canonical_uri get_type);
+use JSON::Schema::Modern::Utilities 0.525 qw(assert_keyword_exists assert_keyword_type E canonical_uri get_type jsonp);
 use Safe::Isa;
 use File::ShareDir 'dist_dir';
 use Path::Tiny;
@@ -137,10 +137,12 @@ sub traverse ($self, $evaluator) {
       callbacks => {
         '$dynamicRef' => sub ($, $schema, $state) {
           push @json_schema_paths, $state->{data_path} if $schema->{'$dynamicRef'} eq '#meta';
+          return 1;
         },
         '$ref' => sub ($data, $schema, $state) {
           push @operation_paths, [ $data->{operationId} => $state->{data_path} ]
             if $schema->{'$ref'} eq '#/$defs/operation' and defined $data->{operationId};
+          return 1;
         },
       },
     },
@@ -152,6 +154,16 @@ sub traverse ($self, $evaluator) {
     return $state;
   }
 
+  # "Templated paths with the same hierarchy but different templated names MUST NOT exist as they
+  # are identical."
+  my %seen_path;
+  foreach my $path (sort keys $schema->{paths}->%*) {
+    my $normalized = $path =~ s/\{[^}]+\}/\x00/r;
+    ()= E({ %$state, data_path => jsonp('/paths', $path) },
+      'duplicate templated path %s', $path) if ++$seen_path{$normalized} > 1;
+  }
+  return $state if $state->{errors}->@*;
+
   my @real_json_schema_paths;
   foreach my $path (sort @json_schema_paths) {
     # disregard paths that are not the root of each embedded subschema.
@@ -238,7 +250,7 @@ JSON::Schema::Modern::Document::OpenAPI - One OpenAPI v3.1 document
 
 =head1 VERSION
 
-version 0.040
+version 0.041
 
 =head1 SYNOPSIS
 
